@@ -9,13 +9,11 @@ use strict ;
 
 use vars qw( $VERSION ) ;
 
-$VERSION = '1.02' ;
-
+$VERSION = '1.04' ;
 
 use Symbol ;
-use Fcntl ;
+use Fcntl qw( :seek O_RDONLY ) ;
 use Carp ;
-use integer ;
 
 my $max_read_size = 1 << 13 ;
 
@@ -50,6 +48,10 @@ BEGIN {
  	*EOF = \&eof ;
  	*CLOSE = \&close ;
  	*TELL = \&tell ;
+
+# added getline alias for compatibility with IO::Handle
+
+	*getline = \&readline ;
 }
 
 
@@ -77,7 +79,7 @@ sub new {
 
 # seek to the end of the file and get its size
 
-	my $seek_pos = sysseek( $handle, 0, 2 ) or return ;
+	my $seek_pos = sysseek( $handle, 0, SEEK_END ) or return ;
 
 # get the size of the first block to read,
 # either a trailing partial one (the % size) or full sized one (max read size)
@@ -160,7 +162,7 @@ sub readline {
 # seek to the beginning of this block and save the new seek position
 
 		$seek_pos -= $read_size ;
-		sysseek( $handle, $seek_pos, 0 ) ;
+		sysseek( $handle, $seek_pos, SEEK_SET ) ;
 		$self->{'seek_pos'} = $seek_pos ;
 
 # read in the next (previous) block of text
@@ -201,6 +203,14 @@ sub tell {
 	$seek_pos + length(join "", @{ $self->{'lines'} });
 }
 
+sub get_handle {
+	my ( $self ) = @_ ;
+
+	my $handle = $self->{handle} ;
+	seek( $handle, $self->tell, SEEK_SET ) ;
+	return $handle ;
+}
+
 sub close {
 
 	my ( $self ) = @_ ;
@@ -263,38 +273,53 @@ basis.
 
 =head1 OBJECT INTERFACE
  
+These are the methods in C<File::ReadBackwards>' object interface:
 
-There are only 2 methods in Backwards' object interface, new and
-readline.
 
 =head2 new( $file, [$rec_sep], [$sep_is_regex] )
 
-New takes as arguments a filename, an optional record separator and an
-optional flag that marks the record separator as a regular
+C<new> takes as arguments a filename, an optional record separator and
+an optional flag that marks the record separator as a regular
 expression. It either returns the object on a successful open or undef
-upon failure. $!  is set to the error code if any.
+upon failure. $! is set to the error code if any.
 
 =head2 readline
 
-Readline takes no arguments and it returns the previous line in the
+C<readline> takes no arguments and it returns the previous line in the
 file or undef when there are no more lines in the file. If the file is
 a non-seekable file (e.g. a pipe), then undef is returned.
 
+=head2 getline
+
+C<getline> is an alias for the readline method. It is here for
+compatibilty with the IO::* classes which has a getline method.
+
 =head2 eof
 
-Eof takes no arguments and it returns true when readline() has
+C<eof> takes no arguments and it returns true when readline() has
 iterated through the whole file.
 
 =head2 close
 
-close takes no arguments and it closes the handle
+C<close> takes no arguments and it closes the handle
 
 =head2 tell
 
-tell takes no arguments and it returns the current filehandle position.
+C<tell> takes no arguments and it returns the current filehandle position.
 This value may be used to seek() back to this position using a normal
 file handle.
 
+=head2 get_handle
+
+C<get_handle> takes no arguments and it returns the internal Perl
+filehandle used by the File::ReadBackwards object.  This handle may be
+used to read the file forward. Its seek position will be set to the
+position that is returned by the tell() method.  Note that
+interleaving forward and reverse reads may produce unpredictable
+results.  The only use supported at present is to read a file backward
+to a certain point, then use 'handle' to extract the handle, and read
+forward from that point.
+
 =head1 TIED HANDLE INTERFACE
 
 =head2 tie( *HANDLE, 'File::ReadBackwards', $file, [$rec_sep], [$sep_is_regex] )
